@@ -44,10 +44,11 @@ using namespace std;
 #include "loadingstatus.h"
 
 #include "externalcom.h"
+
 #ifdef GLOGG_SUPPORTS_DBUS
 #include "dbusexternalcom.h"
-#elif GLOGG_SUPPORTS_WINIPC
-#include "winexternalcom.h"
+#elif GLOGG_SUPPORTS_SOCKETIPC
+#include "socketexternalcom.h"
 #endif
 
 
@@ -59,7 +60,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
-    string filename = "";
+    vector<string> filenames;
 
     // Configuration
     bool new_session = false;
@@ -72,7 +73,7 @@ int main(int argc, char *argv[])
     TLogLevel logLevel = logWARNING;
 
     try {
-        po::options_description desc("Usage: glogg [options] [file]");
+        po::options_description desc("Usage: glogg [options] [files]");
         desc.add_options()
             ("help,h", "print out program usage (this message)")
             ("version,v", "print glogg's version information")
@@ -90,14 +91,14 @@ int main(int argc, char *argv[])
             desc_hidden.add_options()(s.c_str(), "debug");
 
         desc_hidden.add_options()
-            ("input-file", po::value<string>(), "input file")
+            ("input-file", po::value<vector<string>>(), "input file")
             ;
 
         po::options_description all_options("all options");
         all_options.add(desc).add(desc_hidden);
 
         po::positional_options_description positional;
-        positional.add("input-file", 1);
+        positional.add("input-file", -1);
 
         int command_line_style = (((po::command_line_style::unix_style ^
                 po::command_line_style::allow_guessing) |
@@ -143,8 +144,9 @@ int main(int argc, char *argv[])
             if ( vm.count( s ) )
                 logLevel = (TLogLevel) (logWARNING + s.length());
 
-        if ( vm.count("input-file") )
-            filename = vm["input-file"].as<string>();
+        if ( vm.count("input-file") ) {
+            filenames = vm["input-file"].as<vector<string>>();
+        }
     }
     catch(exception& e) {
         cerr << "Option processing error: " << e.what() << endl;
@@ -166,10 +168,13 @@ int main(int argc, char *argv[])
 
     FILELog::setReportingLevel( logLevel );
 
-    if ( ! filename.empty() ) {
-        // Convert to absolute path
-        QFileInfo file( QString::fromStdString( filename ) );
-        filename = file.absoluteFilePath().toStdString();
+    for ( auto& filename: filenames ) {
+        if ( ! filename.empty() ) {
+            // Convert to absolute path
+            QFileInfo file( QString::fromLocal8Bit( filename.c_str() ) );
+            filename = file.absoluteFilePath().toStdString();
+            LOG( logDEBUG ) << "Filename: " << filename;
+        }
     }
 
     // External communicator
@@ -181,10 +186,10 @@ int main(int argc, char *argv[])
         externalCommunicator = make_shared<DBusExternalCommunicator>();
         externalInstance = shared_ptr<ExternalInstance>(
                 externalCommunicator->otherInstance() );
-#elif GLOGG_SUPPORTS_WINIPC
-        externalCommunicator = make_shared<WinExternalCommunicator>();
-        externalInstance = shared_ptr<ExternalInstance>(
-                externalCommunicator->otherInstance() );
+#elif GLOGG_SUPPORTS_SOCKETIPC
+        externalCommunicator = make_shared<SocketExternalCommunicator>();
+        auto ptr = externalCommunicator->otherInstance();
+        externalInstance = shared_ptr<ExternalInstance>( ptr );
 #endif
     }
     catch(CantCreateExternalErr& e) {
@@ -197,7 +202,9 @@ int main(int argc, char *argv[])
         LOG(logINFO) << "Found another glogg (version = "
             << std::setbase(16) << version << ")";
 
-        externalInstance->loadFile( QString::fromStdString( filename ) );
+        for ( const auto& filename: filenames ) {
+            externalInstance->loadFile( QString::fromStdString( filename ) );
+        }
 
         return 0;
     }
@@ -236,7 +243,10 @@ int main(int argc, char *argv[])
 #endif
 
     // We support high-dpi (aka Retina) displays
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps);
+    app.setAttribute( Qt::AA_UseHighDpiPixmaps );
+
+    // No icon in menus
+    app.setAttribute( Qt::AA_DontShowIconsInMenus );
 
     // FIXME: should be replaced by a two staged init of MainWindow
     GetPersistentInfo().retrieve( QString( "settings" ) );
@@ -244,12 +254,22 @@ int main(int argc, char *argv[])
     std::unique_ptr<Session> session( new Session() );
     MainWindow mw( std::move( session ), externalCommunicator );
 
+    // Geometry
+    mw.reloadGeometry();
+
+    // Load the existing session if needed
+    std::shared_ptr<Configuration> config =
+        Persistent<Configuration>( "settings" );
+    if ( load_session || ( filenames.empty() && !new_session && config->loadLastSession() ) )
+        mw.reloadSession();
+
     LOG(logDEBUG) << "MainWindow created.";
     mw.show();
-    // Load the existing session if needed
-    if ( load_session || ( filename.empty() && !new_session ) )
-        mw.reloadSession();
-    mw.loadInitialFile( QString::fromStdString( filename ) );
+
+    for ( const auto& filename: filenames ) {
+        mw.loadInitialFile( QString::fromStdString( filename ) );
+    }
+
     mw.startBackgroundTasks();
 
     return app.exec();
